@@ -1,6 +1,6 @@
 /* 
  Authors
- Martin Schlather, martin.schlather@math.uni-goettingen.de
+ Martin Schlather, schlather@math.uni-mannheim.de
 
  library for simulation and analysis of marked point processes:
     basic input/output
