@@ -1,7 +1,7 @@
 
 /* 
  Authors
- Martin Schlather, martin.schlather@math.uni-goettingen.de
+ Martin Schlather, schlather@math.uni-mannheim.de
 
  library for simulation and analysis of marked point processes:
     simulation of mpp
